'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.default = undefined;

var _webpack = require('webpack');

var _webpack2 = _interopRequireDefault(_webpack);

var _config = require('../webpack/config');

var _config2 = _interopRequireDefault(_config);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

let ServerCompiler = class ServerCompiler {

	constructor(config) {
		this.config = config;
		this.webpackConfig = (0, _config2.default)(this.config);
		this.compiler = (0, _webpack2.default)(this.webpackConfig);
		this.initialCompilationComplete = false;
	}

	build({ restart }) {
		return new Promise(resolve => {
			if (this.config.dev) {
				this.compiler.watch({
					aggregateTimeout: 300,
					poll: true
				}, (...args) => this.onCompilationDone(...args, resolve, restart));
			} else {
				this.compiler.run((...args) => this.onCompilationDone(...args, resolve));
			}
		});
	}

	onCompilationDone(err, stats, resolve, restart = false) {
		if (err) {
			console.error(err.stack || err);
			if (err.details) {
				console.error(err.details);
			}
			return;
		}

		console.log(stats.toString({
			chunks: false, // Makes the build much quieter
			colors: true // Shows colors in the console
		}));

		if (this.initialCompilationComplete) {
			if (restart) {
				restart();
			}
		} else {
			this.initialCompilationComplete = true;
			resolve();
		}
	}
};
exports.default = ServerCompiler;